@@ -1,4 +1,6 @@
-class HTTPException:
+class HTTPException(Exception):
+    __slots__ = ('status', 'message', 'response')
+    
     def __init__(self, response, error_string: str = None):
         self.status = response.status
         self.message = error_string or f'The server responded with a status of {self.status}'
@@ -7,7 +9,7 @@ class HTTPException:
         super().__init__(self.message)
     
     def __repr__(self) -> str:
-        raise f"<HTTPException status={self.status} response={self.response!r}>"
+        return f"<HTTPException status={self.status} response={self.response!r}>"
     
     def __int__(self) -> int:
-        return self.status
\ No newline at end of file
+        return self.status
